 /*
     191206_StataWorkshopCode.do
     Christine Leibbrand
     12/6/2019
     Code for Introduction to Stata Workshop: 
	 renaming, labeling, missing values, creating variables, subsetting (keep)
*/

*************************
***Reading in the Data***
*************************

*** Set working directory (this is where Stata will save and retrieve files)
cd "H:\Workshops\NLSY_StataWorkshop\"

*** Get data file
use "NLSY_StataWorkshop.dta", replace

*************************************
***Renaming and Labeling Variables***
*************************************

*** Renaming variables
*Try to decide on a naming convention early on, if you have longitudinal data, consider conventions for designating year
rename KEYSEX_1997 gender_1997
rename KEYRACE_ETHNICITY_1997 raceeth_1997
rename YSCH_37000_1997 safesch_1997

***Labeling variables
label variable gender_1997 "KEYSEX_1997, self-reported gender"
label variable raceeth_1997 "KEYRACE_ETHNICITY_1997, self-reported race/ethnicity"
label variable safesch_1997 "YSCH_37000_1997, respondent report of agreement they feel safe at school"

***Check your work
tab gender_1997
tab raceeth_1997
tab safesch_1997

***EXERCISE 1: Rename and label variables on worksheet

******************************
***Labeling Variable Values***
******************************

*** Define label
label define racelabel 1 "1 Black" 2 "2 Hispanic" ///
			3 "3 Mixed Race (Non-Hispanic)" 4 "4 Non-Black/Non-Hispanic"
						 
*** Apply label
label values raceeth_1997 racelabel

*** Check work
tab raceeth_1997

*label drop racelabel

*** Create/define two more labels
   label define genderlabel	/// 
            		 1 "1 Male" ///
                     2 "2 Female" ///
			         0 "0 No Information" 
	label values gender_1997 genderlabel
	
	tab gender_1997

label define genhealthlab -4 "-4 Valid Skip" ///
-3 "-3 Invalid Skip" ///
-2  "-2 Don’t Know" ///
1 "1 Excellent" ///
2 "2 Very Good" ///
3 "3 Good" ///
4 "4 Fair" ///
5 "5 Poor"

label values genhealth_1997 genhealthlab

tab genhealth_1997

*EXERCSE 2: Create and apply a value label to ownedu_1997 and then tabulate to check your work

*EXERCSE 3: Create and apply a value label safesch_1997 to and then tabulate to check your work

********************
***Missing Values***
********************

***Strategy 1: Recode
*Recoding a single missing value for a variable
recode ownedu_1997 (-3 = .)
tab ownedu_1997, missing

*Recoding multiple missing values for a variable                     
recode momedu_1997 (-3 = .i) (-4 =.v) (95 = .m)
tab momedu_1997, missing 

*Missing value coding variables safe school and general health
recode safesch_1997 genhealth_1997 (-1 -2 -3  -4 = . )
tab safesch_1997, m
tab genhealth_1997, m

***Strategy 2: mvdecode
*Code missing values in batches and even for entire dataset
*Only do this if missing value conventions are known to be consistent throughout the entire dataset

*mvdecode _all, mv(-1 = .r \ -2 = .d \ -3 = .i  \ -4 = .v \ -5 = .n \ -7 = .m)
*mvdecode varlist, mv(-1 = .r \ -2 = .d \ -3 = .i  \ -4 = .v \ -5 = .n \ -7 = .m)

*EXERCISE 4: Set missing values for favicecr_1997 and dadedu_1997

***Save data set with changes made above
save "191206_StataWorkshop_CEL.dta", replace

****************************
***Creating New Variables***
****************************

***Sometimes we will need to create new variables based off of the existing variables in our dataset

*** Example 1: Suppose we want to create a categorical variable for dad's education with 0 = Less than HS, 1 = HS Degree, 2 = Some College, 3 = College Degree, 4 = College+

*Setting a new variable = . ensures we don't accidentally put in values that don't exist
gen dadedu_cat_1997 = .

*Now we add in our values using replace and using "if" statements to specify how values will be added in
replace dadedu_cat_1997 = 0 if(dadedu_1997<12)
replace dadedu_cat_1997 = 1 if(dadedu_1997==12)
replace dadedu_cat_1997 = 2 if(dadedu_1997>12 & dadedu_1997<16)
replace dadedu_cat_1997 = 3 if(dadedu_1997==16)
replace dadedu_cat_1997 = 4 if(dadedu_1997>16 & dadedu_1997<95)

*Check your work
tab dadedu_1997 dadedu_cat_1997,m

*** Example 2: Create a dichotomous variable indicating if the respondents agrees or strongly agrees that they feel safe at school (= 1) or if the respondent disagrees or strongly disagrees that they feel safe at school (= 0) based on the responses to the question safesch_1997.

*Generate dichotomous variable and set it = .
gen safesch_cat_1997 = .

*Add in values based on respondents' answers to safesch_1997 question
replace safesch_cat_1997 = 1 if(safesch_1997 == 1| safesch_1997 == 2)
replace safesch_cat_1997 = 0 if(safesch_1997 >= 3 & safesch_1997 <= 4)


*Check your work
tab safesch_1997 safesch_cat_1997,m

*EXERCISE 5: Create a dichotomous variable indicating if the respondent reports having excellent/very good/good health (=1) or whether the respondent reports having fair/poor health (=0) in response to the genhealth_1997 measure

*************************
***Subsetting the Data***
*************************

*** Subset the data -- keep only those variables that have been renamed and labeled
keep PUBID_1997 gender_1997 raceeth_1997 momedu_1997 dadedu_1997 ownedu_1997 genhealth_1997 safesch_1997

*** Save this new data set
save "191206_StataWorkshop_subset_CEL.dta", replace

*** Subset the data -- keep only females 
keep if gender_1997 == 2

*** Save this new data set
save "191206_StataWorkshop_female_CEL.dta", replace



